pub(crate) async fn migrate_to_v8(
ctx: GeneralDbMigrationFnContext<'_>,
) -> Result<(), DbMigrationError>Expand description
Adds the invoice expiry to registered incoming contract records so stale records can be pruned.
pub(crate) async fn migrate_to_v8(
ctx: GeneralDbMigrationFnContext<'_>,
) -> Result<(), DbMigrationError>Adds the invoice expiry to registered incoming contract records so stale records can be pruned.